# Ze40 south pointing Config

## zen40az180_dl1ab_tuned_nsb_psf_src2

## Short description of the config

Config for ze40 and south pointing with PSF and NSB tuned on data

## Why this config is needed

Processing of data for which tuned MC is missing
